# Copyright (C) 2018-2024 by BDE ENS Paris-Saclay
# SPDX-License-Identifier: GPL-3.0-or-later

from random import shuffle

from django import forms
from django.utils.translation import gettext_lazy as _
from django.utils import timezone
from member.models import Club
from note_kfet.inputs import Autocomplete, DateTimePickerInput
from note_kfet.middlewares import get_current_request
from permission.backends import PermissionBackend

from .models import BasicFood, TransformedFood


class BasicFoodForms(forms.ModelForm):
    """
    Form for add non-transformed food
    """
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['name'].widget.attrs.update({"autofocus": "autofocus"})
        self.fields['name'].required = True
        self.fields['owner'].required = True

        # Some example
        self.fields['name'].widget.attrs.update({"placeholder": _("pasta")})
        clubs = list(Club.objects.filter(PermissionBackend.filter_queryset(get_current_request(), Club, "change")).all())
        shuffle(clubs)
        self.fields['owner'].widget.attrs["placeholder"] = ", ".join(club.name for club in clubs[:4]) + ", ..."

    class Meta:
        model = BasicFood
        fields = ('name', 'owner', 'date_type', 'expiry_date', 'allergens')
        widgets = {
            "owner": Autocomplete(
                model=Club,
                attrs={"api_url": "/api/members/club/"},
            ),
            'expiry_date': DateTimePickerInput(),
        }


class TransformedFoodForms(forms.ModelForm):
    """
    Form for add transformed food
    """
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['name'].widget.attrs.update({"autofocus": "autofocus"})
        self.fields['name'].required = True
        self.fields['owner'].required = True
        self.fields['creation_date'].required = True
        self.fields['creation_date'].initial = timezone.now
        self.fields['is_active'].initial = True

        # Some example
        self.fields['name'].widget.attrs.update({"placeholder": _("lasagna")})
        clubs = list(Club.objects.filter(PermissionBackend.filter_queryset(get_current_request(), Club, "change")).all())
        shuffle(clubs)
        self.fields['owner'].widget.attrs["placeholder"] = ", ".join(club.name for club in clubs[:4]) + ", ..."

    class Meta:
        model = TransformedFood
        fields = ('name', 'creation_date', 'owner', 'is_active', 'allergens')
        widgets = {
            "owner": Autocomplete(
                model=Club,
                attrs={"api_url": "/api/members/club/"},
            ),
            'creation_date': DateTimePickerInput(),
        }
